
// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of asciival, software which can return an ASCII
// representation of the data read from a DAP server.

// Copyright (c) 2002,2003 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// asciival is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2, or (at your option) any later
// version.
// 
// asciival is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
// 
// You should have received a copy of the GNU General Public License along
// with GCC; see the file COPYING. If not, write to the Free Software
// Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
// (c) COPYRIGHT URI/MIT 1998,2000
// Please read the full copyright statement in the file COPYRIGHT_URI.
//
// Authors:
//      jhrg,jimg       James Gallagher <jgallagher@gso.uri.edu>

// Implementation for AsciiList. See AsciiByte.cc
//
// 3/12/98 jhrg

#include "config_asciival.h"

#include <iostream>
#include <string>

#include "InternalErr.h"
#include "AsciiList.h"
#include "name_map.h"

extern bool translate;
extern name_map names;

List *
NewList(const string &n, BaseType *v)
{
    return new AsciiList(n, v);
}

BaseType *
AsciiList::ptr_duplicate()
{
    return new AsciiList(*this);
}

AsciiList::AsciiList(const string &n, BaseType *v) : List(n, v)
{
}

AsciiList::~AsciiList()
{
}

bool 
AsciiList::read(const string &)
{
  throw InternalErr(__FILE__, __LINE__, "Called unimplemented read method");
}

#if 0
void 
AsciiList::print_val(ostream &os, string, bool print_decl_p)
{
    // Print the name and size of the variable. Note that I print the size
    // information while initializing the vector #shape#. 3/9/98 jhrg
    if (print_decl_p)
	os << names.lookup(name(), translate) << ", ";
    
    int len = length();
    for (int i = 0; i < len; ++i) {
	BaseType *v = var(i);
	bool print_name_p = false;

	if (v->is_constructor_type())
	    print_name_p = true;

	var(i)->print_val(os, "", print_name_p);
	if (i < len-1)		// Comma after all but last element
	    os << ", ";
    }
}
#endif

// $Log: AsciiList.cc,v $
// Revision 1.6.4.1  2003/07/11 04:28:18  jimg
// Boldly (ahem) removed the GNUG interface/implementation #pragma.
// compared object sizes; there's a little difference, but it looks like a
// draw as to which is bigger.
//
// Revision 1.6  2003/01/27 19:38:23  jimg
// Updated the copyright information.
// Merged with release-3-2-6.
//
// Revision 1.5  2001/09/28 23:46:06  jimg
// merged with 3.2.3.
//
// Revision 1.4.4.1  2001/09/18 23:29:26  jimg
// Massive changes to use the new AsciiOutput class. Output more or less
// conforms to the DAP Spec. draft.
//
// Revision 1.4  2000/10/02 20:09:52  jimg
// Moved Log entries to the end of the files
//
// Revision 1.3  1999/07/28 23:00:53  jimg
// Separated from the writeval directory, moved to tools
//
// Revision 1.2  1999/03/24 06:23:42  brent
// convert String.h to std lib <string>, convert to packages regex -- B^2
//
// Revision 1.1  1998/03/13 21:25:17  jimg
// Added
//
